Change history — PyEPR 0.6.1 documentation

### Navigation

- index
- previous |
- PyEPR 0.6.1 documentation »

# Change history

## PyEPR 0.6.1 (26/04/2012)

- fix compatibility with cython 0.16
- added a new option to the setup script (--epr-api-src) to build PyEPR using the EPR-API C sources

## PyEPR 0.6 (12/08/2011)

- full support for Python 3
- improved code highligh in the documentation
- depend from cython >= 0.13 instead of cython >= 0.14.1. Cythonizing `epr.pyx` with Python 3 requires cython >= 0.15

## PyEPR 0.5 (25/04/2011)

- stop using `PyFile_AsFile()` that is no more available in Python 3
- now documentation uses intersphinx capabilities
- code examples added to documentation
- tutorials added to documentation
- the LICENSE.txt file is now included in the source distribution
- the cython construct `with nogil` is now used instead of calling `Py_BEGIN_ALLOW_THREADS()` and `Py_END_ALLOW_THREADS()` directly
- dropped old versions of cython; now cython 0.14.1 or newer is required
- suppressed several constness related warnings

## PyEPR 0.4 (10/04/2011)

- fixed a bug in the `epr.Product.__str__()`, `Dataset.__str__()` and `erp.Band.__repr__()` methods (bad formatting)
- fixed `epr.Field.get_elems()` method for char and uchar data types
- implemented `epr.Product.read_bitmask_raster()`, now the `epr.Product` API is complete
- fixed segfault in `epr.Field.get_unit()` method when the field has no unit
- a smaller dataset is now used for unit tests
- a new tutorial section has been added to the user documentation

## PyEPR 0.3 (01/04/2011)

- version string of the EPR C API is now exposed as module attribute `epr.EPR_C_API_VERSION`
- implemented `__repr__`, `__str__`, `__eq__`, `__ne__` and `__iter__` special methods
- added utility methods (not included in the C API) like:
  - `epr.Record.get_field_names()`
  - `epr.Record.fields()`
  - `epr.Dataset.records()`
  - `epr.Product.get_dataset_names()`
  - `epr.Product.get_band_names()`
  - `epr.Product.datasets()`
  - `epr.Product.bands()`
- fixed a logic error that caused empty messages in custom EPR exceptions

## PyEPR 0.2 (20/03/2011)

- sphinx documentation added
- added docstrings to all method and classes
- renamed some method and parameter in order to avoid redundancies and have a more pythonic API
- in case of null pointers a `epr.EPRValueError` is raised
- improved C library shutdown management
- introduced some utility methods to `epr.Product` and `epr.Record` classes

## PyEPR 0.1 (09/03/2011)

Initial release

### Navigation

- index
- previous |
- PyEPR 0.6.1 documentation »